#
# spec file for package chafa
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           chafa
Version:        1.8.0
Release:        bp154.3.8.1
Summary:        Image-to-text converter for terminal
License:        LGPL-3.0-or-later
Group:          Amusements/Toys/Graphics
URL:            https://hpjansson.org/chafa/
Source0:        https://github.com/hpjansson/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Patch0:         chafa-CVE-2022-1507.patch
Patch1:         chafa-CVE-2022-2061.patch
Patch2:         chafa-CVE-2022-2301.patch
BuildRequires:  ImageMagick-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc
BuildRequires:  glib2-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
Requires:       libchafa0 = %{version}

%description
Chafa is a command-line utility that converts all kinds of images, including
animated image formats like GIFs, into ANSI/Unicode character output that can
be displayed in a terminal.

%package -n libchafa0
Summary:        Shared library for %{name}
Group:          Development/Libraries/C and C++

%description -n libchafa0
The core of Chafa which converts all kinds of images, including
animated image formats like GIFs, into ANSI/Unicode characters.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libchafa0 = %{version}

%description devel
Development files for %{name}.

%package doc
Summary:        Chafa documentation
Group:          Documentation/HTML
Recommends:     %{name}-devel
BuildArch:      noarch

%description doc
Documentation for %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
autoreconf -ivf

# rpath
sed -i -e 's|hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
       -e 's|runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
       -e "s|runpath_var='LD_RUN_PATH'|runpath_var=DIE_RPATH_DIE|g" \
    configure

%build
%configure --disable-rpath
%make_build

%install
%make_install
rm -rf %{buildroot}%{_libdir}/libchafa.{a,la}

%post -n libchafa0 -p /sbin/ldconfig
%postun -n libchafa0 -p /sbin/ldconfig

%files
%license COPYING.LESSER
%doc README* NEWS
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files -n libchafa0
%license COPYING.LESSER
%{_libdir}/lib%{name}.so.0*

%files devel
%license COPYING.LESSER
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so
%dir %{_libdir}/chafa/
%{_libdir}/chafa/include/

%files doc
%doc AUTHORS
%license COPYING.LESSER
%doc %{_datadir}/gtk-doc/html/%{name}

%changelog
* Tue Jul  5 2022 Michael Vetter <mvetter@suse.com>
- bsc#1201211 (CVE-2022-2301): Fix buffer over-read
  * Add chafa-CVE-2022-2301.patch
* Wed Jun 15 2022 Michael Vetter <mvetter@suse.com>
- bsc#1200510 (CVE-2022-2061): Fix heap based buffer overflow
  in lzw_decode
  * Add chafa-CVE-2022-2061.patch
* Thu Apr 28 2022 Michael Vetter <mvetter@suse.com>
- bsc#1198965 (CVE-2022-1507): Fix NULL pointer deref in gif_internal_decode_frame
  * Add chafa-CVE-2022-1507.patch
* Wed Sep  1 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.8.0:
  * Added basic support for the Kitty and iTerm2 graphics protocols.
    These are enabled automatically when corresponding terminal support
    is detected, or manually with -f kitty or -f iterm.
  * Implemented an 8-color mode, selectable with -c 8
  * Implemented a foreground-only switch, --fg-only. This produces
    character art using foreground colors only, and will avoid
    modifying or resetting the background color. Looks best with
    non-contiguous symbols (e.g. ascii).
  * Added builtins for Japanese kana fullwidth symbols. These can
    now be used without loading any external fonts (try -c none --symbols wide).
  * Added builtins for legacy computer symbols (mainly wedges and
    sextant blocks). These were widely used in PETSCII and Teletext,
    and can be enabled using --symbols or --fill with their respective
    tags: legacy, wedge and sextant (@hodefoting).
  * Since there is a growing number of builtin symbols that may not
    be available everywhere, the default selection has been restricted
    to the widely supported block and border sets.
  * If possible, we now select a visually blank character from the
    specified symbol/fill sets instead of hardcoding ASCII space for
    featureless cells. One practical upshot of this is that the constant-width
    braille range can be used to produce consistent images even in contexts
    with variable-width fonts. U+2800 (BRAILLE PATTERN BLANK) will then be used in blank cells.
  * Improved terminal size detection when used with pipelines and redirection.
    This should now produce an image properly sized for your terminal:
    curl https://i.imgur.com/WFDEFVg.jpeg | chafa - | tee out
  * ChafaCanvas gained API functions for programmatically getting and
    setting character cell contents. These are used in a new example
    in tests/ncurses.c demonstrating ncurses integration.
  * Made --disable-rpath the default in order to simplify packaging.
  * Added a HACKING file featuring a much needed release checklist.
  * Improved terminal support:
    + Ctx will now use optimizing REP sequences at high -O levels.
    + foot now defaults to sixels.
    + iTerm2 now defaults to the iTerm2 protocol.
    + Kitty now defaults to the Kitty protocol.
    + st now defaults to truecolor symbols.
  * Bug fixes:
    + #44 Missing error handling on stdout writes.
    + [unfiled] Solid symbols erroneously replaced by fill in FGBG mode.
    + [unfiled] Integer formatter was not using fast path for 8-bit values.
* Mon Jun  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.1:
  * Add NOCONFIGURE variable to autogen.sh to skip configure
  Bug fixes:
  * #50 SIGBUS while loading huge GIFs
  * #52 Produces small glitches in output with some images
  * #54 Haiku port fails on 32bit
  * [unfiled] Exclude RTL code points that could break the output.
  * [unfiled] Apple Terminal lacks truecolor support, so make it
    default to 256 colors
  * [unfiled] Fix typo affecting middle dot symbol.
* Fri Jan 15 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.0:
  * Added support for fullwidth symbols that take up two character
    cells. These are common in East Asian scripts. Single-cell and
    double-cell symbols can be mixed, and -f symbols mode will use
    both if possible.
  * New symbol tags: alpha, digit, alnum, narrow, wide, ambiguous,
    ugly, bad. "Ambiguous" symbols have uncertain widths and may
    render poorly in some terminals. "Ugly" denotes symbols that
    are unsuitable for Chafa's cell-based graphics (multicolor
    emoji, ideographic descriptors, etc). "Bad" is a superset of
    these two categories. Bad symbols are always excluded unless
    explicitly enabled with e.g. CHAFA_SYMBOL_TAG_BAD (--symbols
    +bad in the frontend).
  * The font loader (--glyph-file option) now does a better job
    with proportional fonts.
  * Added options for controlling lossless optimization of output.
    Currently, attribute reuse and character repetition (REP
    sequence) are implemented.
  * Added -O option to the frontend. This controls the optimization
    level.
  * Added a simple abstraction layer for terminal control sequences
    (ChafaTermInfo and ChafaTermDb). This allows for improved
    terminal support.
  * FbTerm is now supported with TERM=fbterm in the environment.
  * Bug fixes:
  - #43 Fix signal handler.
  - [unfiled] Crash when invalid font paths were passed on command line.
  - [unfiled] Small typo in fontgen's READM).
  - [unfiled] Bad contrast adjustment in images with transparency.
* Sun Apr 12 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * Added configure option --disable-rpath. This allows packagers to
    prevent the hard-coded library search path from being embedded in
    the chafa command-line tool (Mo Zhou, #39).
  * Added defaults for the yaft terminal.
  Bug fixes:
  * #40 - Fails to build on hurd-i386 + other i386 (reported by Mo
    Zhou).
  * [unfiled] - Rare failed assert with mostly transparent sixel image
    (reported by Reddit user spryfigure).
  * [unfiled] - Minor typo in function docstring.
* Thu Apr  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.0:
  * Added sixel graphics support. Chafa will automatically produce sixels
    if the connected terminal supports it. It can also be forced using the
    new -f or --format flag. This is a new implementation written from the
    ground up to maximize throughput.
  * Added the --glyph-file option, which loads glyph-symbol mappings from
    any file format supported by FreeType (TTF, PCF, etc). This allows for
    custom font support and improved symbol selection.
  * Added the --speed option specifying animation speed. It accepts a
    unitless multiplier, a specific number of frames per second, or max
    for maximum throughput.
  * There are now two ways to assign colors to symbol cells. Formerly,
    this was done based on the average color of the covered area. The new
    default is to use the median color, which produces sharper edges,
    but is slightly more prone to high-frequency noise. The new option
  - -color-extractor selects the method to employ.
  * When displaying multiple files, the default delay between files has
    been changed from three seconds to zero. Animations will still play
    through once. This can be overridden on the chafa command line with -d
    or --duration.
  * Minor tweaks to built-in symbols.
  Performance improvements:
  * Halved pixel storage requirements from 64 bits to 32 bits,
    resulting in significant memory savings.
  * Now builds with -ffast-math, yielding a big speedup for DIN99d.
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.2.2:
  * Fix #34 Cannot compile example
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
- Avoid double-shipping documentation, and make docs noarch.
* Tue Aug 20 2019 mvetter@suse.com
- Update to 1.2.1:
  * Detect kitty and mlterm virtual terminals and apply optimal
    defaults accordingly
  * Make Automake build more strict and fix a few compatibility nits
  * Fix #30 - Failed to build on hurd-i386
  * Fix crash on certain broken GIFs
* Mon Aug  5 2019 mvetter@suse.com
- Update to 1.2.0:
  * Added --dither, --dither-grain and --dither-intensity options.
    These allow for sub-cell dithering in quantized modes (none,
    2, 16, 240 and 256). Especially beneficial when used with
  - p off.
  * Added API for ordered and diffusion-based dithering in quantization.
  * Added API support for multiple 8bpc pixel modes: RGB, BGR, RGBA,
    BGRA, ARGB, ABGR with either premultiplied or unassociated alpha channels.
  * Smooth scaling is now done internally, meaning libchafa
    consumers no longer need to prescale images.
  * Implemented a machine learning tool that can generate custom
    fonts for efficient image reproduction from a provided dataset.
    This is left uninstalled since it's still experimental
  * Throughput improvements:
    + GIF animations now start playing instantly.
    + GIF CPU overhead reduced by 75%%, peak memory use down 95%%-99%% (!).
    + XWD common case CPU overhead down 60-70%%, peak memory down 70%%.
    + Additional halving of CPU overhead in 240- and 256-color modes.
    + Streamlined pixel pipeline for better parallelization.
  * Installation instructions:
    + New: Guix (Guy Fleury Iteriteka).
    + New: openSUSE (@jubalh).
  * Bug fixes:
    + [unfiled] Certain SVGs had transparency replaced with a white background (nemo).
    + [unfiled] -lm dependency belongs in libchafa, not frontend.
* Fri Feb  8 2019 mvetter@suse.com
- Initial package chafa 1.0.1 for openSUSE
